# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2022-2025, by Samuel Williams.

module Sus
	module Fixtures
		module Async
			module HTTP
				VERSION = "0.12.1"
			end
		end
	end
end
